@@ -166,14 +166,14 @@ class Selenium(Scraper):
         time.sleep(seconds) # sleep for N seconds
         action.release().perform()
 
-    def on_click(self, path: str, element: any=None, timeout: int=0) -> any:
+    def on_click(self, path: str, element: any=None, timeout: int=0, pos: int=0) -> any:
         if element is None and path is not None:
             element = self.xPath(path=path, element=element, timeout=timeout)
         
         if element is not None:
             if type(element) is list:
                 if len(element) > 0:
-                    element = element[0]
+                    element = element[pos]
                 else:
                     return None
             try:
